@@ -9,7 +9,7 @@
 # You should have received a copy of the GNU General Public License along with seacarb; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-"Khs"              <- function (S=35,T=25,P=0)
+"Khs"              <- function (S=35,T=25,P=0,pHscale="T")
 
 #--------------------------------------------------------------
 # Dissociation constant of H2S
@@ -17,13 +17,14 @@
 
 {
 
-nK <- max(length(S), length(T), length(P))
+nK <- max(length(S), length(T), length(P), length(pHscale))
 
 ##-------- Creation de vecteur pour toutes les entrees (si vectorielles)
 
 if(length(S)!=nK){S <- rep(S[1], nK)}
 if(length(T)!=nK){T <- rep(T[1], nK)}
 if(length(P)!=nK){P <- rep(P[1], nK)}
+if(length(pHscale)!=nK){pHscale <- rep(pHscale[1], nK)}
 
 
 tk = 273.15           # [K] (for conversion [deg C] <-> [K])
@@ -51,8 +52,19 @@ lnkpok0 <- rep(0, nK)
   }
 }
   Khs      <- exp(lnK +lnkpok0)  # K_H2S on total scale
+
+###----------------pH scale corrections
+factor <- rep(NA,nK)
+pHsc <- rep(NA,nK)
+for(i in (1:nK)){   
+ if(pHscale[i]=="T"){factor[i] <- 1 ; pHsc[i] <- "total scale"}
+ if(pHscale[i]=="F"){factor[i] <- kconv(S=S[i], T=T[i], P=P[i])$ktotal2free ; pHsc[i] <- "free scale"}
+ if(pHscale[i]=="SWS"){factor[i] <- kconv(S=S[i], T=T[i], P=P[i])$ktotal2SWS ; pHsc[i] <- "seawater scale"}
+Khs[i] <- Khs[i]*factor[i]
+}
+
   attr(Khs,"unit")     = "mol/kg-soln"
-  attr(Khs,"pH scale") = "total hydrogen ion concentration"
+  attr(Khs,"pH scale") = pHsc
   return(Khs)
 
 }  ## END Khs
